#include "sensor_msgs/Range.h"
#include "math.h"


int main(int argc, char **argv)
{

  sensor_msgs::Range r;
  float y = 360.0f;
  int z = 360u;
  long x;
  y = 1e-10.0;
  x = 360LL;
  x = 360L;
  x = 360l;

}
